import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

import unittest
import CPSSkinsTestCase


class TestPortalStyles(CPSSkinsTestCase.CPSSkinsTestCase):

    def afterSetUp(self):
        tmtool = self.portal.portal_themes
        if 'PortalTheme' in tmtool.objectIds():
           tmtool.manage_delObjects(['PortalTheme'])
        self.theme_container = tmtool.addPortalTheme(empty=1)


    def test_addPortalStyle_Color(self):
        theme_container = self.theme_container
        theme_container.addPortalStyle(type_name='Area Color')
        theme_container.addPortalStyle(type_name='Area Color')
        styles = theme_container['styles'].objectValues()
        stylenames = [getattr(s,'title') for s in styles]
        self.assertEquals(['AreaColor1', 'AreaColor2'], stylenames)
        for s in theme_container['styles'].objectValues():
            self.assert_(s.aq_explicit.isPortalStyle())
            self.assert_(s.render())
            self.assert_(s.preview())

    def test_addPortalStyle_Shape(self):
        theme_container = self.theme_container
        theme_container.addPortalStyle(type_name='Area Shape')
        theme_container.addPortalStyle(type_name='Area Shape')
        styles = theme_container['styles'].objectValues()
        stylenames = [getattr(s,'title') for s in styles]
        self.assertEquals(['AreaShape1', 'AreaShape2'], stylenames)
        for s in theme_container['styles'].objectValues():
            self.assert_(s.aq_explicit.isPortalStyle())
            self.assert_(s.render())
            self.assert_(s.preview())
            
    def test_addPortalStyle_BoxShape(self):
        theme_container = self.theme_container
        theme_container.addPortalStyle(type_name='Portal Box Shape')
        theme_container.addPortalStyle(type_name='Portal Box Shape')
        styles = theme_container['styles'].objectValues()
        stylenames = [getattr(s,'title') for s in styles]
        self.assertEquals(['PortalBoxShape1', 'PortalBoxShape2'], stylenames)
        for s in theme_container['styles'].objectValues():
            self.assert_(s.aq_explicit.isPortalStyle())
            self.assert_(s.render())
            self.assert_(s.preview())

    def test_addPortalStyle_BoxColor(self):
        theme_container = self.theme_container
        theme_container.addPortalStyle(type_name='Portal Box Color')
        theme_container.addPortalStyle(type_name='Portal Box Color')
        styles = theme_container['styles'].objectValues()
        stylenames = [getattr(s,'title') for s in styles]
        self.assertEquals(['PortalBoxColor1', 'PortalBoxColor2'], stylenames)
        for s in theme_container['styles'].objectValues():
            self.assert_(s.aq_explicit.isPortalStyle())
            self.assert_(s.render())
            self.assert_(s.preview())

    def test_addPortalStyle_FontColor(self):
        theme_container = self.theme_container
        theme_container.addPortalStyle(type_name='Font Color')
        theme_container.addPortalStyle(type_name='Font Color')
        styles = theme_container['styles'].objectValues()
        stylenames = [getattr(s,'title') for s in styles]
        self.assertEquals(['FontColor1', 'FontColor2'], stylenames)
        for s in theme_container['styles'].objectValues():
            self.assert_(s.aq_explicit.isPortalStyle())
            self.assert_(s.render())
            self.assert_(s.preview())

    def test_addPortalStyle_FontShape(self):
        theme_container = self.theme_container
        theme_container.addPortalStyle(type_name='Font Shape')
        theme_container.addPortalStyle(type_name='Font Shape')
        styles = theme_container['styles'].objectValues()
        stylenames = [getattr(s,'title') for s in styles]
        self.assertEquals(['FontShape1', 'FontShape2'], stylenames)
        for s in theme_container['styles'].objectValues():
            self.assert_(s.aq_explicit.isPortalStyle())
            self.assert_(s.render())
            self.assert_(s.preview())

    def test_addPortalStyle_CollapsibleMenuStyle(self):
        theme_container = self.theme_container
        theme_container.addPortalStyle(type_name='Collapsible Menu Style')
        theme_container.addPortalStyle(type_name='Collapsible Menu Style')
        styles = theme_container['styles'].objectValues()
        stylenames = [getattr(s,'title') for s in styles]
        self.assertEquals(['CollapsibleMenuStyle1', 'CollapsibleMenuStyle2'], stylenames)
        for s in theme_container['styles'].objectValues():
            self.assert_(s.aq_explicit.isPortalStyle())
            self.assert_(s.render())
            self.assert_(s.preview())

    def test_addPortalStyle_CalendarStyle(self):
        if 'portal_calendar' in self.portal.objectIds():
            theme_container = self.theme_container
            theme_container.addPortalStyle(type_name='Calendar Style')
            theme_container.addPortalStyle(type_name='Calendar Style')
            styles = theme_container['styles'].objectValues()
            stylenames = [getattr(s,'title') for s in styles]
            self.assertEquals(['CalendarStyle1', 'CalendarStyle2'], stylenames)
            for s in theme_container['styles'].objectValues():
                self.assert_(s.aq_explicit.isPortalStyle())
                self.assert_(s.render())
                self.assert_(s.preview())

    def test_rename_style(self):
        theme_container = self.theme_container
        style1 = theme_container.addPortalStyle(type_name='Font Shape')
        style2 = theme_container.addPortalStyle(type_name='Font Shape')
        style1.edit(title='title1')
        style2.edit(title='title2')
        self.assert_(getattr(style1, 'title'), 'title1')
        self.assert_(getattr(style2, 'title'), 'title2')
        # rename to an existing style name
        style2.edit(title='title1')
        self.assert_(getattr(style2, 'title'), 'title11')
 
    def test_sanitize_style_title(self):
        theme_container = self.theme_container
        style = theme_container.addPortalStyle(type_name='Area Color')
        title = ' a sd %&1 -BfG ./\+*'
        style.edit(title=title)
        title = getattr(style, 'title')
        self.assertEquals(title, 'asd1BfG')

    def test_style_rebuild(self):
        theme_container = self.theme_container
        style = theme_container.addPortalStyle(type_name='Area Color')
        style.rebuild()


def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestPortalStyles))
    return suite
    
if __name__ == '__main__':
    framework(descriptions=1, verbosity=2)

